#
# spec file for package xdm
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _dminitdir %{_prefix}/lib/X11/displaymanagers
%if 0%{?suse_version} >= 1550
%define UsrEtcMove 1
%endif
#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir %{_localstatedir}/adm/fillup-templates
%endif
Name:           xdm
Version:        1.1.17
Release:        3.1
Summary:        X Display Manager
License:        MIT
Group:          System/X11/Utilities
URL:            https://xorg.freedesktop.org/
Source0:        http://xorg.freedesktop.org/releases/individual/app/%{name}-%{version}.tar.xz
Source1:        xdm.tar.bz2
Source2:        HOWTO.xdm
Source4:        display-manager-legacy.service
Source5:        xsession.desktop
# Upstream version doesn't handle display-manager.service
Source6:        xdm.service
Patch1:         xdm-tolerant-hostname-changes.diff
Patch2:         xdm-tarball.patch
Patch3:         n_Allow-the-greeter-to-set-the-input-fields-bg-color.patch
Patch4:         xinit-UsrEtcMove.patch
BuildRequires:  firewall-macros
BuildRequires:  libtool
BuildRequires:  pam-devel
BuildRequires:  pkgconfig
BuildRequires:  systemd-rpm-macros
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xau)
BuildRequires:  pkgconfig(xaw7)
BuildRequires:  pkgconfig(xdmcp)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xft)
BuildRequires:  pkgconfig(xinerama)
BuildRequires:  pkgconfig(xmu)
BuildRequires:  pkgconfig(xorg-macros) >= 1.4
BuildRequires:  pkgconfig(xpm)
BuildRequires:  pkgconfig(xt)
BuildRequires:  pkgconfig(xtrans)
Requires:       /sbin/startproc
Requires:       cpp
Requires:       logrotate
Requires:       sessreg
Requires:       xconsole
Recommends:     feh
Recommends:     xinit
Requires:       xmessage
Requires:       xrdb
Requires:       xset
Requires:       xsetroot
Requires:       xterm-bin
Recommends:     dbus-1-x11
Recommends:     xdmbgrd
# This was part of the xorg-x11 package up to version 7.6
Conflicts:      xorg-x11 <= 7.6
%{?systemd_requires}
%if 0%{?suse_version} >= 1550
Requires:       %{_bindir}/pidof
%else
Requires:       /sbin/pidof
%endif
Requires:       displaymanager-sysconfig
Requires(post): displaymanager-sysconfig
# Ensure display-manager.service symlink is created in %post
Requires(pre):  systemd-presets-common-SUSE

%description
Xdm manages a collection of X displays, which may be on the local host
or remote servers.

%package xsession
Summary:        User/System Xsession Desktop File
Group:          System/X11/Utilities
Requires:       xdm
Enhances:       xdm

%description xsession
This package contains the System desktop file which will cause
the execution of a user provided $HOME/.xsession script or pick
the system wide DM default set in %{_sysconfdir}/sysconfig/displaymanager.

%package -n displaymanager-sysconfig
Summary:        Central configuration for Display Managers
Requires:       %fillup_prereq

%description -n displaymanager-sysconfig
openSUSE tries to concentrate common configuration of multiple display managers
in a central place (/etc/sysconfig/displaymanager). The most relevant setting to
configure there is AUTOLOGIN.

This package is required by the various display managers that integrate into the config hooks.

%prep
%setup -q
cp %{SOURCE2} .
cd xdm
%patch -P 1 -p1
cd -
# reverse apply (boo#1130321)
%patch -P 3 -p1 -R

%build
# needed for patch0
autoreconf -fi
%configure \
        --disable-static \
        --with-pam \
        --with-xdmconfigdir=%{_sysconfdir}/X11/xdm \
        --with-xdmscriptdir=%{_sysconfdir}/X11/xdm \
        --with-piddir=%{_rundir} \
        --with-systemdsystemunitdir=no
%make_build

%install
%make_install
# Not used anymore by SuSE
cd "%{buildroot}/%{_sysconfdir}/X11/xdm/"
rm -fv GiveConsole TakeConsole Xsetup_0
cd -

cd %{buildroot}
# SuSE default XDM configuration
tar -xf %{SOURCE1}
%if 0%{?UsrEtcMove}
patch -p1 < %{PATCH2}
mkdir -p usr%{_sysconfdir}/X11/xdm
mv etc/X11/xdm/* usr%{_sysconfdir}/X11/xdm
# Edited by SUSEConfig.xdm, package a copy
for i in xdm-config Xservers; do
	cp usr%{_sysconfdir}/X11/xdm/$i etc/X11/xdm/$i
done
mkdir -p ./%{_pam_vendordir}
rm etc/pam.d/xdm.sle15 etc/pam.d/xdm-np.sle15
mv etc/pam.d/* ./%{_pam_vendordir}/
%else
patch -p0 < %{PATCH4}
rm etc/pam.d/xdm etc/pam.d/xdm-np
mv etc/pam.d/xdm.sle15 etc/pam.d/xdm
mv etc/pam.d/xdm-np.sle15 etc/pam.d/xdm-np
%endif
%if "%{_fillupdir}" != "%{_localstatedir}/adm/fillup-templates"
  mkdir -p %{buildroot}$(dirname %{_fillupdir})
  mv %{buildroot}%{_localstatedir}/adm/fillup-templates \
     %{buildroot}$(dirname %{_fillupdir})
%endif

%ifarch s390 s390x
sed -i -e "s+DISPLAYMANAGER_REMOTE_ACCESS=.*+DISPLAYMANAGER_REMOTE_ACCESS=\"yes\"+g" \
       -e "s+DISPLAYMANAGER_STARTS_XSERVER=.*+DISPLAYMANAGER_STARTS_XSERVER=\"no\"+g" \
    %{buildroot}%{_fillupdir}/sysconfig.displaymanager
%endif
cd -

# Correct location (FHS-2.1)
%if 0%{?UsrEtcMove}
ln -s %{_localstatedir}/lib/xdm/authdir %{buildroot}%{_distconfdir}/X11/xdm/authdir
%else
ln -s %{_localstatedir}/lib/xdm/authdir %{buildroot}%{_sysconfdir}/X11/xdm/authdir
%endif
# bnc#223734
rm %{buildroot}%{_libdir}/X11/xdm/libXdmGreet.la
# for FHS compliance (bnc#21857)
mv %{buildroot}%{_libdir}/X11/xdm/chooser %{buildroot}%{_bindir}
# fdo#35868 (closed INVALID, but because of above fix, we want it)
ln -s xdm.8%{?ext_man} %{buildroot}%{_mandir}/man8/chooser.8%{?ext_man}
install -D %{SOURCE5} -m 0644 %{buildroot}%{_datadir}/xsessions/xsession.desktop
rm -f %{buildroot}%{_sbindir}/rcxdm
install -D %{SOURCE4} -m 0444 %{buildroot}%{_unitdir}/display-manager-legacy.service
ln -sf service %{buildroot}%{_sbindir}/rcdisplay-manager
cat > %{buildroot}%{_sbindir}/rcxdm <<-'EOF'
	#!/bin/bash
	exec -a rcdisplay-manager %{_sbindir}/rcdisplay-manager ${1+"$@"}
	EOF
chmod 0755 %{buildroot}%{_sbindir}/rcxdm
# prepare for defaul-dm to be chosen by means of update-alternatives
mkdir -p %{buildroot}%{_sysconfdir}/alternatives
touch %{buildroot}%{_sysconfdir}/alternatives/default-displaymanager
ln -s %{_sysconfdir}/alternatives/default-displaymanager %{buildroot}%{_prefix}/lib/X11/displaymanagers/default-displaymanager
# Inject a dummy 'console' selection - which used to be choice in /etc/sysconfig/displaymanager
touch %{buildroot}%{_prefix}/lib/X11/displaymanagers/console

%if 0%{?UsrEtcMove}
mkdir -p %{buildroot}%{_distconfdir}/logrotate.d
mv %{buildroot}%{_sysconfdir}/logrotate.d/xdm %{buildroot}%{_distconfdir}/logrotate.d/xdm
%endif

install -Dm0644 %{SOURCE6} %{buildroot}%{_unitdir}/xdm.service

%post
# enable Xorg on s390x with virtio (Redhat PCI ID 1af4:1050) on installation (but not upgrade)
if [ $1 -eq 1 ] ; then
  if [ "$(arch)" = "s390x" ]; then
    if [ -d /dev/dri ]; then
      sed -i -e "s+DISPLAYMANAGER_REMOTE_ACCESS=.*+DISPLAYMANAGER_REMOTE_ACCESS=\"no\"+g" \
             -e "s+DISPLAYMANAGER_STARTS_XSERVER=.*+DISPLAYMANAGER_STARTS_XSERVER=\"yes\"+g" \
          %{_fillupdir}//sysconfig.displaymanager
    fi
  fi
fi
%service_add_post display-manager-legacy.service
%service_add_post xdm.service
%{_sbindir}/update-alternatives --install %{_prefix}/lib/X11/displaymanagers/default-displaymanager \
  default-displaymanager %{_prefix}/lib/X11/displaymanagers/console 5
%{_sbindir}/update-alternatives --install %{_prefix}/lib/X11/displaymanagers/default-displaymanager \
  default-displaymanager %{_prefix}/lib/X11/displaymanagers/xdm 10
# get rid of DISPLAYMANAGER in /etc/sysconfig/displaymanager (boo#1125040)
sed -i 's/DISPLAYMANAGER=.*//g' %{_sysconfdir}/sysconfig/displaymanager
%firewalld_reload

%pre
%service_add_pre display-manager-legacy.service
%service_add_pre xdm.service

%postun
# Do not restart DM on update (bnc#886641)
%if 0%{?suse_version} >= 1550
%service_del_postun_without_restart display-manager-legacy.service
%service_del_postun_without_restart xdm.service
%else
%service_del_postun -n display-manager-legacy.service
%service_del_postun -n xdm.service
%endif
[ -f %{_prefix}/lib/X11/displaymanagers/console ] || %{_sbindir}/update-alternatives \
  --remove default-displaymanager %{_prefix}/lib/X11/displaymanagers/console
[ -f %{_prefix}/lib/X11/displaymanagers/xdm ] || %{_sbindir}/update-alternatives \
  --remove default-displaymanager %{_prefix}/lib/X11/displaymanagers/xdm

%preun
%service_del_preun display-manager-legacy.service
%service_del_preun xdm.service

%post -n displaymanager-sysconfig
%{fillup_only -n displaymanager}

%files
%license COPYING
%doc AUTHORS ChangeLog README.md
%doc HOWTO.xdm
%dir %{_dminitdir}
%{_dminitdir}/xdm
%{_dminitdir}/console
%{_prefix}/lib/X11/displaymanagers/default-displaymanager
%ghost %{_sysconfdir}/alternatives/default-displaymanager
%if 0%{?UsrEtcMove}
%dir %{_distconfdir}/X11
%{_distconfdir}/X11/xdm/
%endif
%config %{_sysconfdir}/X11/xdm/
%if 0%{?UsrEtcMove}
%dir %{_distconfdir}/X11/xdm/scripts
%else
%dir %{_sysconfdir}/X11/xdm/scripts
%endif
%dir %{_prefix}/lib/firewalld
%dir %{_prefix}/lib/firewalld/services
%{_prefix}/lib/firewalld/services/x11.xml
%{_unitdir}/display-manager-legacy.service
%{_unitdir}/xdm.service
%{_prefix}/lib/X11/display-manager
%if 0%{?UsrEtcMove}
%{_distconfdir}/logrotate.d/xdm
%else
%config %{_sysconfdir}/logrotate.d/xdm
%endif
%if 0%{?UsrEtcMove}
%{_pam_vendordir}/xdm
%{_pam_vendordir}/xdm-np
%else
%config(noreplace) %{_sysconfdir}/pam.d/xdm
%config(noreplace) %{_sysconfdir}/pam.d/xdm-np
%endif
%dir %{_localstatedir}/lib/xdm/
%{_localstatedir}/lib/xdm/authdir/
%ghost %{_localstatedir}/log/xdm.errors
%{_bindir}/chooser
%{_bindir}/xdm
%{_sbindir}/rcxdm
%{_sbindir}/rcdisplay-manager
%{_libdir}/X11/xdm/
%dir %{_datadir}/X11/app-defaults
%{_datadir}/X11/app-defaults/Chooser
%{_mandir}/man8/chooser.8%{?ext_man}
%{_mandir}/man8/xdm.8%{?ext_man}
%ifnarch %{ix86}
%dir %{_libdir}/X11
%endif

%files xsession
%{_datadir}/xsessions/xsession.desktop

%files -n displaymanager-sysconfig
%{_fillupdir}/sysconfig.displaymanager

%changelog
* Wed Jun  4 2025 Stefan Dirsch <sndirsch@suse.com>
- no longer require xinit so it can be dropped from SLE16
* Tue Mar 25 2025 Callum Farmer <gmbr3@opensuse.org>
- Move display-manager.service to display-manager-legacy.service
  to prepare for systemd control of display manager choice
  (needs systemd-presets-common-SUSE update)
- Create xdm.service to allow XDM to be used in systemd only mode
- Order systemd-presets-common-SUSE before xdm
* Sun Mar  9 2025 Stefan Dirsch <sndirsch@suse.com>
- Update to release 1.1.17
  Support for using getaddrinfo(), inet_ntop(), and struct sockaddr_storage
  was originally added to support IPv6, and only used if IPv6 support was
  enabled. Two decades later, these interfaces are ubiquitous and OS'es have
  starting marking the old interfaces as deprecated, so this release changes
  to use the modern interface whenever we can now.  (Note that code included
  from xtrans will only use these interfaces when IPv6 is disabled if building
  against xtrans 1.6.0 or later.)
* Sat Mar  1 2025 Jan Engelhardt <jengelh@inai.de>
- Make build recipe compatible with POSIX sh.
* Wed Feb 26 2025 Dominique Leuenberger <dimstar@opensuse.org>
- display-manager: Do not abort when there is no /usr/bin/X found.
  Rely on the DM to know how to handle it. E.g gdm could be
  spawning a wayland-only session. (boo#1237777)
* Wed Nov 27 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Split out displaymanager-sycconfig package: The central
  configuration part that is used by all display managers. This is
  needed in order to progress towards 'xdm' not acting as wrapper
  around DMs, but only be used as Dislplay Manager when XDM is
  supposed to be used, or use the real systemd services of the
  various DMs (e.g gdm.service, sddm.service).
* Wed Nov 20 2024 pgajdos@suse.com
- tweak the login screen:
  * use sans serif font
  * use branding wallpaper and colors
  * do not require xli, recommend feh
* Fri Aug  9 2024 Thorsten Kukuk <kukuk@suse.com>
- sysconfig/windowmanager is deprecated since 7 years, don't
  read it if it does not exist.
* Fri Apr  5 2024 Stefan Dirsch <sndirsch@suse.com>
- Update to release 1.1.16
  * This release fixes a failure to build with the recent libXaw 1.0.16
    release due to a change introduced in xdm 1.1.15 to address gcc 14
    build issues.
* Sun Mar 24 2024 Stefan Dirsch <sndirsch@suse.com>
- Update to release 1.1.15
  * This release fixes a failure to build with the upcoming gcc 14,
    cleans up several other compiler warnings, fixes a bug in the
    generation of the xdm.service file for systemd, and removes a
    lot of dead code checks for platforms & features that have not
    been supported since the conversion from Imake to autoconf in
    2005.
-  supersedes u_gcc14-fix.patch
* Wed Mar  6 2024 Stefan Dirsch <sndirsch@suse.com>
- u_gcc14-fix.patch
  * fix build against gcc14 (boo#1221028)
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Thu May 11 2023 Stefan Dirsch <sndirsch@suse.com>
- since xrdb no longer requires cpp, it needs to be reqired here now
* Mon Apr  3 2023 Stefan Dirsch <sndirsch@suse.com>
- Create two set of pam configuration files:
  + *.sle15 are for SLES15 and older
  + add postlogin-* includes to the others as required by new
    openSUSE's PAM config policy
* Thu Mar 23 2023 Stefan Dirsch <sndirsch@suse.com>
- No longer run "localectl set-x11-keymap ..." and only run
  "localectl set-keymap ..." if XKBLAYOUT is not set, i.e. if
  nobody was making use of "localectl set-x11-keymap" after
  installation (boo#1209594, comment#24)
* Wed Mar 22 2023 Stefan Dirsch <sndirsch@suse.com>
- keytable: exit 0 was executed too early, so
  "localectl set-x11-keymap" wasn't executed; fixed this
  (boo#1209594, comment#19)
* Wed Mar 22 2023 Stefan Dirsch <sndirsch@suse.com>
- keytable: no longer ignore XKBLAYOUT (and XKBMODEL, XKBVARIANT,
  XKBOPTIONS) variables if available in /etc/vconsole.conf, i.e.
  no longer overwrite keyboard settings if anybody used
  "localectl set-x11-keymap" himself; fixed "check systemd mapping"
  if KEYMAP_TOGGLE has been set (boo#1209594)
* Sun Dec  4 2022 Stefan Dirsch <sndirsch@suse.com>
- Update to release 1.1.14
  * This release improves compatibility for building with GNU
    libc 2.36, and adds a --without-xinerama option to the
    configure script for those who want to build without linking
    to libXinerama.
- supersedes u_glibc-2.36.patch
* Thu Oct 13 2022 Stefan Dirsch <sndirsch@suse.com>
- display-manager.service: simplified deps (boo#1203662)
  * remove deps to time-sync.target, remote-fs.target, dbus.socket,
    getty@tty7.service, plymouth-quit.service
  * keep Conflicts to plymouth-quit.service
  * keep dep to systemd-logind.service
* Tue Oct 11 2022 Frederic Crozat <fcrozat@suse.com>
- Update xdm-tarball.patch:
  * create /etc/X11/xinit directory if not present.
* Fri Sep  9 2022 Callum Farmer <gmbr3@opensuse.org>
- Add u_glibc-2.36.patch: use glibc's arc4random instead of
  libbsd's (bsc#1202222)
* Fri Aug 19 2022 Dirk Müller <dmueller@suse.com>
- add buildrequires for bsd/stdlib.h (bsc#1202222)
* Tue Aug  9 2022 Thorsten Kukuk <kukuk@suse.com>
- Use %%_pam_vendordir
* Thu Jun 30 2022 Stefan Schubert <schubi@suse.de>
- Moved logrotate files from user specific directory /etc/logrotate.d
  to vendor specific directory /usr/etc/logrotate.d.
* Mon Apr  4 2022 Stefan Dirsch <sndirsch@suse.com>
- udpate to release 1.1.13
  * bugfix release
* Wed Feb  9 2022 Stefan Dirsch <sndirsch@suse.com>
- added "Recommends: xdmbgrd" to make sure we have a background for
  xdm and the xdmbgrd package is required by anyone and not silently
  dropped by accident (boo#1195664)
* Tue Feb  8 2022 Dirk Müller <dmueller@suse.com>
- fix bashism in postinstall script (bsc#1195391)
* Fri Nov 19 2021 Stefan Dirsch <sndirsch@suse.com>
- %%post: enable Xorg on s390x with virtio (Redhat PCI ID 1af4:1050)
  via /etc/sysconfig/displaymanager on installation (but not upgrade)
  by checking for existence of /dev/dri [JIRA#SLE-18632]
* Mon May 17 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Do not own /usr/share/xsessions: this directory is owned by the
  filesystem package.
* Tue Mar 16 2021 Dirk Müller <dmueller@suse.com>
- modernize spec (move license to licensedir)
* Mon Jan  4 2021 Stefan Dirsch <sndirsch@suse.com>
- fixed path of pidof tool for older openSUSE Leap releases
  (boo#1179607)
* Tue Dec  1 2020 Stefan Dirsch <sndirsch@suse.com>
- fixed %%postun for older releases than factory/TW (see change
  right below, which broke it)
* Tue Nov  3 2020 Franck Bui <fbui@suse.com>
- Replace  '%%service_del_postun -n' with '%%service_del_postun_without_restart'
  '-n' is deprecated and will be removed in the future.
* Mon Oct 12 2020 Stefan Dirsch <sndirsch@suse.com>
- no longer package symlinks for Xsession, Xsetupm Xstartup and
  Xreset in /etc/X11/xdm, since meanwhile sddm, gdm and lightdm
  have been adjusted
* Mon Oct  5 2020 Stefan Dirsch <sndirsch@suse.com>
- removed /etc/X11/xdm/Keyboard.map since it meanwhile has been
  replaced by /usr/share/systemd/kbd-model-map (used by YaST)
* Sun Oct  4 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Don't create the compat symlinks in /etc on the fly, track them
  properly as %%config
* Sat Oct  3 2020 Stefan Dirsch <sndirsch@suse.com>
- /etc/X11/xdm/scripts/11-ssh-agent
  * ssh-askpass now moved to /usr/libexec/ssh (boo#1175991)
* Tue Sep 29 2020 Stefan Dirsch <sndirsch@suse.com>
- moved xdm/xdm-np PAM files to /usr/etc/pam.d, since lightdm has
  been adjusted meanwhile
* Tue Sep 15 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Switch to /usr/bin/pidof dependency, provided by procps-ng.
* Thu Sep 10 2020 Stefan Dirsch <sndirsch@suse.com>
- fixes in xdm-tarball.patch
  * /usr/lib/X11/display-manager: fixes sddm, which didn't use
    xdm_reload_files in xdm_start_proc() of
    /usr/lib/X11/displaymanagers/sddm (boo#1173049)
* Wed Sep  9 2020 Stefan Dirsch <sndirsch@suse.com>
- fixes in xdm-tarball.patch
  * symlink also $XDMDIR/xinitrc.common in /etc/X11/xinit; it
    is still often sourced in old ~/.xinitrc user files ...
* Wed Sep  9 2020 Stefan Dirsch <sndirsch@suse.com>
- fixes in xdm-tarball.patch
  * fixed include path for generic Xresources in xdm's Xresources file
  * fixed $XDMDIR in Xsession, so sys.xsession can be found
  * sys.xsession: fixed syntax error in code, which reads
    additional xdm scripts
  * display-manager: also symlink Xstartup and Xreset in
    /etc/X11/xdm (needed by lighdm)
- specfile:
  * for now use again /etc/pam.d for xdm/xdm-np PAM files instead
    of /usr/etc/pam.d (using the latter resulted in
    "authentificataion failure" with lightdm)
* Tue Sep  8 2020 Stefan Dirsch <sndirsch@suse.com>
- reenabled move to /usr/etc/X11/xdm; updated xdm-tarball.patch
  (includes changes from xinit-UsrEtcMove.patch) [boo#1176212]
* Tue Sep  8 2020 Stefan Dirsch <sndirsch@suse.com>
- xinit-UsrEtcMove.patch
  * changes needed with xinitrc moving to %%{_libexecdir}/xinit and
    xinitrc.common moving to /usr/etc/X11/xinit/
* Tue Sep  8 2020 Stefan Dirsch <sndirsch@suse.com>
- reverted move to /usr/etc/X11/xdm for now due to boo#1176212
* Sat Sep  5 2020 Stefan Dirsch <sndirsch@suse.com>
- updated xdm-tarball.patch
  * adjusted for changes in xmodmap and xinit (boo#1173049)
* Fri Sep  4 2020 Stefan Dirsch <sndirsch@suse.com>
- xdm-tarball.patch
  * /usr/etc changes still needed for xdm.tar.bz2; will need
    more changes once xmodmap and xinit files are also moved to
    /usr/etc (boo#1173049)
* Fri Sep  4 2020 Stefan Dirsch <sndirsch@suse.com>
- move /etc/X11/xdm --> /usr/etc/X11/xdm and
  /etc/pam.d -> /usr/etc/pam.d; still TODO: adjust scripts in
  xdm.tar.bz2 (boo#1173049)
* Fri Sep  4 2020 Stefan Dirsch <sndirsch@suse.com>
- more cleanup
  * no longer support sle12; adjusted xdm.tar.bz2 and
    applied xdm-with-update-alternative.patch to this tarball
* Fri Sep  4 2020 Stefan Dirsch <sndirsch@suse.com>
- cleanup
  * get rid of xdm-fallbacks.tar.bz2, which wasn't used any longer
    since SUSE 12.1
  * no longer support systmed based OSes like SUSE < 12.1 and sle11;
    removed therefore also xdm-consolekit.diff
  * no longer support sle11
* Fri Aug 28 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Require /sbin/startproc: with systemd no longer pulling in
  sysvinit-tools. we are responsible for our own deps. /sbin/pidof
  and /sbin/startproc both were presented by sysvinit-tools. but
  the sole presence of the /sbin/pidof dep is not sufficient, as
  this can be provided by various packages (e.g.
  busybox-sysvinit-tools, which then does not provide startproc).
  Spelling the deps out ensures that we get the right package set
  installed.
* Thu Aug 27 2020 Franck Bui <fbui@suse.com>
- Drop insserv-compat dependency when display-manager.service is used
  insserv-compat is going to be dropped soon or later on systems with
  systemd as init system.
  It was only needed by /usr/lib/X11/display-manager script that uses
  rc_status to pretty print the status of a command.
  Since this script is intended to be used by display-manager.service
  and not called directly by users and systemd has already its own
  mechanism to report status, the use of rc_status doesn't seem to be
  useful.
  The exit failure status for each command has been preserved.
* Wed Aug 26 2020 Franck Bui <fbui@suse.com>
- Drop commands in /usr/lib/X11/display-manager that are never used by systemd
  Assuming that this script is only called from
  display-manager.service unit, some commands of the scripts are
  either never used or redundant with systemd functionalities.
  More specifically, there's no need to redefine a "stop" command as
  this is one basic command that systemd implements already.
  Also convert "reload" to make use of $MAINPID exported by systemd
  which should be slighly more reliable and hence stop relying on
  killproc that might be removed in the future.
* Wed Aug 26 2020 Franck Bui <fbui@suse.com>
- Replace /var/run with /run as /var/run is obsolete since quite some
  time now.
* Thu Jul 16 2020 Stefan Dirsch <sndirsch@suse.com>
- readd insserv-compat also when using systemd due to missing
  /etc/rc.status, etc. (boo#1174180)
* Mon Jun 22 2020 Cristian Rodríguez <crrodriguez@opensuse.org>
- Require fillup_prereq not insserv-compat when using systemd
* Fri Jun  5 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Fixes for %%_libexecdir changing to /usr/libexec
* Sat Mar 21 2020 Stefan Dirsch <sndirsch@suse.com>
- README.security: fixed and improved documentation about how to
  enable xdmcp for xdm (boo#1167293)
* Tue Jan 28 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Require insserv-compat: /usr/lib/X11/display-manager sources
  /etc/rc.status, which is part of insserv-compat. Without this
  present, display-manager fails to start up.
* Mon Aug 19 2019 Stefan Dirsch <sndirsch@suse.com>
- pam.d/xdm{,-np}: added pam_keyinit.so (boo#1144063)
* Thu Mar 28 2019 Stefan Dirsch <sndirsch@suse.com>
- n_Allow-the-greeter-to-set-the-input-fields-bg-color.patch
  * reverse applied in order to fix greeter again; related to our
    heavily adjusted xdm Xresources (boo#1130321)
* Sun Mar  3 2019 Stefan Dirsch <sndirsch@suse.com>
- udpate to release 1.1.12
  * This release collects 7 years worth of bug fixes and code
    cleanups, including the fix for CVE-2013-2179 that was
    previously distributed as a patch against the prior release.
* Wed Feb 13 2019 sndirsch@suse.com
- %%post: get rid of DISPLAYMANAGER in /etc/sysconfig/displaymanager
  (boo#1125040)
* Tue Dec 11 2018 msrb@suse.com
- Add OnFailure=plymouth-quit.service to display-manager service.
  (bsc#1118121)
* Thu Jul 26 2018 sndirsch@suse.com
- display-manager: also quit plymouth when display-manager is set
  to console (boo#1102584)
* Tue Jul 17 2018 werner@suse.de
- Change /etc/X11/xdm/scripts/10-gpg-agent to get it work with
  every gpg version 2.1 and up (boo#1062105)
* Wed Jul 11 2018 fcrozat@suse.com
- Update xdm.tar.bz2, no longer create / update /var/lib/X11/X
  symlink, it is no used anymore (FATE#325524).
* Thu Apr  5 2018 werner@suse.de
- systemd-logind integration requires to use -keeptty with X server
  to hold the controlling tty (and breaks startx!).[boo#1088365]
- Do not generate an error on not existing shell functions *_vars
  in /usr/lib/X11/display-manager
* Fri Mar 16 2018 sndirsch@suse.com
- require xinit, since /etc/X11/xdm/Xsession and /etc/X11/xdm/sys.xsession
  are sourcing /etc/X11/xinit/xinitrc.common (boo#1084655)
* Fri Mar  9 2018 sndirsch@suse.com
- check for available graphics during runtime instead of %%post,
  since %%post may already run during image building time in our
  buildsystem (boo#1039497)
* Mon Feb 26 2018 sndirsch@suse.com
- fixed syntax in /usr/lib/firewalld/services/x11.xml (boo#1082890)
* Wed Feb 21 2018 sndirsch@suse.com
- switch from SUSEfirewall2 to firewalld:
  /etc/sysconfig/SuSEfirewall2.d/services/xdmcp -->
  /usr/lib/firewalld/services/x11.xml; only handle Xserver TCP/UDP
  ports 6000-6063; XDMCP port 177 will be handled by firewalld
  package itself and pushed upstream by firewalld maintainers
  (boo#1082033)
* Thu Feb  8 2018 sndirsch@suse.com
- xdm.tar.bz2/Xstartup
  * reverted workaround for DISPLAY being set to 'null', since the
    bug is supposed to be fixed properly in gdm now (bsc#1068016)
* Mon Dec  4 2017 sndirsch@suse.com
- xdm.tar.bz2/usr/lib/X11/display-manager
  * Improve error message with "x11failsafe: in kernel commandline,
    if xorg.conf.install doesn't exist (https://github.com/SUSE/kiwi/issues/554)
* Thu Nov 23 2017 sndirsch@suse.com
- move /var/adm/fillup-templates/sysconfig.displaymanager
  to %%_fillupdir on TW and sle15/Leap 15
* Thu Nov 23 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Thu Nov 23 2017 sndirsch@suse.com
- xdm.tar.bz2: Fix Xstartup, that couldn't handle env DISPLAY=(null)
  (bsc#1068016, patch by xwang@suse.com)
* Fri Oct 27 2017 msrb@suse.com
- Use %%config(noreplace) for /etc/pam.d/* files. The configuration
  files from pam package use the same policy. (bnc#1065399)
* Wed Oct 18 2017 sndirsch@suse.com
- reintroduced /etc/X11/xdm/keytable script and the hook-up in
  /usr/lib/X11/display-manager to setup X11 keymaps, since YaST
  is not able to use localectl already during installation due to
  dbus and appropriate systemd services not running :-(
  (bsc#1046436)
* Thu Oct 12 2017 dimstar@opensuse.org
- Have update-alternatives handle Xinit's integration of the
  displaymanager, replacing /etc/sysconfig/displaymanager.
- Add a dummy entry for 'console' - which is special-cased in the
  display-manager script to 'exit early'. In order for it to become
  an option for update-alternatives, the target needs to exist.
- Update /usr/lib/X11/display-manager to get the
  default-displaymanager from the update-alternative setting
  instead of reading it from /etc/sysconfig/displaymanager.
- Remove DISPLAYMANAGER from displaymanager.sysconfig template.
- Add xdm-with-update-alternative.patch so the needed changes can
  be applied for suse_version >= 1330 only, not breaking Leap 42.x.
- All that together solves boo#1053863.
* Tue Jul 25 2017 sndirsch@suse.com
- fix usage of readlink in Xsession (boo#1050328)
* Mon Jul 24 2017 sndirsch@suse.com
- %%post
  * make previous change in /etc/sysconfig/displaymanager instead
    of /var/adm/fillup-templates/sysconfig.displaymanager
* Mon Jul 24 2017 sndirsch@suse.com
- %%post
  * Do no try to start Xserver on platforms which may ship without
    graphics card (bsc#1039497)
* Mon Feb  6 2017 sndirsch@suse.com
- no longer try to configure Linux console and X11 keymaps
  according to setting in /etc/vconsole.conf; this needs to be done
  via localectl by YaST itself now; /etc/X11/xdm/keytable removed
  and no longer invoked by /usr/lib/X11/display-manager (bnc#1023211)
* Wed Jan  4 2017 sndirsch@suse.com
- remove DISPLAYMANAGER_SHUTDOWN from sysconfig settings
  (bnc#1018045)
* Mon Dec  5 2016 werner@suse.de
- Be sure that display managers will be started *after* systemd's
  login manager (boo#1013200)
* Tue Aug 23 2016 eich@suse.com
- spec-file:
  Move '%%fillup_only -n displaymanager' into %%else
  clause of test for initV/systemd as this is only
  required for systemd.
* Mon Jun 20 2016 eich@suse.com
- Change 'Supplements: xdm' to 'Enhances: xdm'
  to accomodate the Gnome community (boo#981372).
* Fri Jun  3 2016 pjanouch@suse.de
- spec-cleaner cleanups
* Fri Jun  3 2016 eich@suse.com
- xdm.tar.bz2:
  sys.xsession - factor out scriptlets to add services
  to start in the context of a desktop session. These
  scriptlets sould be shipped with their respective
  services, not with xdm.
  Check etc/X11/sdm/scripts/xsession-sriptlets.HOWTO for
  further details (boo#972787).
* Wed May 25 2016 werner@suse.de
- Simplify dbus detection to support all kind of (boo#980521)
- Avoid option --write-env-file for newer gpg (boo#972787)
* Fri May  6 2016 eich@suse.com
- Make SUSEconfig handler for DISPLAYMANAGER_XSERVER_TCP_PORT_6000_OPEN
  robust against changes to the default setting of -listen/-nolisten tcp
  (boo#978262).
* Wed May  4 2016 eich@suse.com
- Prevent xdm.service from being built. We've got display-manager.service
  instead (bsc#978458).
* Wed Mar 30 2016 eich@suse.com
- xsession.desktop file:
  * created xsession sub-package for this file.
  * changed descriptive message to "User/System Default"
  (boo#971852).
* Wed Mar 30 2016 eich@suse.com
- xdm.tar.bz:
  Fixed Xsession script to cull the locale form the arguments before
  passing them on (boo#973045).
* Thu Mar  3 2016 eich@suse.com
- After boo#968405 got fixed in /etc/rpm/macros.systemd, resurrect the old
  behavior of %%postun (boo#968405).
* Sat Feb 27 2016 eich@suse.com
- xdm.tar.bz:
  * /etc/X11/xdm/sys.xsession:
    fix regression from fix for boo#967002 (boo#968172).
  * /etc/X11/xdm/Xsession:
    + Add comments for documentation
    + Fix semantics
    + Don't use $HOME/.xinitrc as session script. Let sys.xession
    handle this.
    + Make argument parser more robust:
    add parse error detection.
  * Add an 'xsession' desktop file: this should offer a session
    where the $HOME/.xsession is used (boo#968631).
* Fri Feb 26 2016 eich@suse.com
- Remove %%service_del_postun display-manager.service
  from %%postun macro (boo#968405).
* Wed Feb 17 2016 werner@suse.de
- Touch /etc/X11/xdm/sys.xsession for boo#967002 that is simply
  add attachment #66582 by using GNUPGHOME variable.
* Wed Feb 17 2016 eich@suse.com
- xdm.tar.bz2:
  * Test for the presence of $HOME/.gnupg/gpg-agent.conf before
    attemting to access it (boo#967002).
- xdm.spec:
  * Fix %%suse_version checking to work on Leap 42.1 as well.
* Wed Nov  4 2015 eich@suse.com
- rename SuSEconfig.xdm
  * /etc/X11/xdm/SuSEconfig.xdm -> /etc/X11/xdm/SUSEconfig.xdm
  * created a symlink for the old file (bsc#953563).
* Fri Oct 16 2015 dimstar@opensuse.org
- Fix the same TakeDevice racing bug also in /etc/init.d/xdm, which
  is an almost exact copy of /usr/lib/X11/display-manager.
- Set the installation of the systemd based service again to be
  valid on Leap (thus, in fact, not really caring for the bug in
  /etc/init.d/xdm).
* Wed Oct  7 2015 dimstar@opensuse.org
- Fix display-manager wrapper: only call TakeDevices in case $DM
  actually fails to start. This was the reason why gdm often failed
  to start with permission denied (depending on timing, gdm might
  fired up X before TakeDevices passed, X would receive the tty7
  by means of logind and TakeDevices reset the permissions again)
  (boo#939594).
* Mon Sep 14 2015 dimstar@opensuse.org
- display-manager.service: require and conflict getty@tty7.service:
  this is copied from gdm.service and is hopefully helping with
  the race condition, where X is often not able to start up on
  VT7 due to missing permissions. (boo#939594)
* Tue Aug  4 2015 eich@suse.com
- Replaced font resources for login screen with font face names.
  Since xdm is now built with Xft support, it uses face names for
  client side rendered fonts. The settings for screen widths >= 800
  are the xdm defaults. For smaller screens the sizes are reduced
  so they fit the screen better (bsc#940263).
* Sat Aug  1 2015 eich@suse.com
- Avoid confusion of user: add '-' to font names in etc/X11/xdm/Xresources.
  This is not required for the font names used in the file but some others.
  (bsc#940263).
* Fri Jul 31 2015 sndirsch@suse.com
- display-manager: don't try to kill DM if it's no longer running
  (bsc#939843)
* Wed Jul 29 2015 werner@suse.de
- Add some used programs to the requirement of xdm
- Use xli aka xsetbg if xpmroot is not available (hint from
  jemoreno@novell.com)
* Mon Jul 20 2015 sndirsch@suse.com
- rename README.SuSE file to README.SUSE (bnc#938737, FATE#316521)
* Tue Mar 17 2015 dvlaeev@suse.com
- We do have graphics on Power with KVM, so remove ppc64le from
  changing displaymanager sysconfig
* Thu Jan 29 2015 sndirsch@suse.com
- /etc/X11/xdm/keytable"
  * improved warning message, when mapping for console keyboard
    doesn't exist (bnc#914880)
* Sun Jan 18 2015 opensuse.lietuviu.kalba@gmail.com
- Don't truncate filenames of lt.baltic.map.gz, lt.std.map.gz,
  lt.l4.map.gz and defkeymap_V1.0 too much (bnc#897803).
* Wed Dec 17 2014 dimstar@opensuse.org
- On openSUSE > 13.2, xterm has been split into xterm-bin for the
  program and xterm for the app launcher. We only need the program,
  so conditionall Require xterm-bin.
* Mon Dec 15 2014 Led <ledest@gmail.com>
- fix bashisms in /etc/X11/xdm/* scripts
* Wed Dec  3 2014 gber@opensuse.org
- unset TMPDIR before executing the final user scripts/shell
  (boo#907041)
- start a login shell when using lksh/mksh
* Wed Oct  8 2014 werner@suse.de
- Use the option (--)enable-ssh-support of the gpg-agent if the
  user has configured this (boo#899647)
* Thu Oct  2 2014 sndirsch@suse.com
- sysconfig.displaymanager/DM list: added lightdm,sddm; removed
  kdm3,kdm4 (bnc#898876)
* Tue Aug  5 2014 sndirsch@suse.com
- replaced 'Also=' by 'Alias=' in display-manager.service
  (bnc#890413)
- make sure not to restart DM on package update; remove confusing
  comment about no longer existing %%%%stop_on_removal,
  %%restart_on_update macros from specfile (bnc#886641)
* Tue Jul 15 2014 sndirsch@suse.com
- udpate to release 1.1.11
- refreshed xdm-tolerant-hostname-changes.diff, xdm-consolekit.diff
- supersedes the following patches:
  U_xdm_config-AC_LIBTOOL_DLOPEN-is-required-for-dynamic-lin.patch,
  U_xdm_Fix-missing-linking-dependency-on-ldl.patch,
  U_xdm_config-use-libtool-export-dynamic-option-for-reverse.patch
* Wed May 28 2014 fcrozat@suse.com
- Use KillMode=process for systemd service, this ensures Xorg won't
  receive SIGKILL while switching to runlevel 3 [bnc#871808].
- Add "Also=xdm.service" to display-manager.service to better
  handle migration.
* Fri May 23 2014 jsegitz@novell.com
- added necessary macros for systemd files
* Thu May 15 2014 arichardson.kde@gmail.com
- Don't run dbus-launch if the socket /run/user/<uid>/bus exists, since
  this means that dbus is already handled by systemd
* Tue May 13 2014 coolo@suse.com
- just don't "package" pid file. It's called xdm.pid, so it's pretty
  obvious what package it is from
- take the pid file out of the xdm.tar
* Mon Mar 24 2014 sndirsch@suse.com
- DISPLAYMANAGER_STARTS_XSERVER needs to be set to "no" on s390x
  and ppc64le (bnc#869267)
* Fri Mar 21 2014 werner@suse.de
- Move forward to systemd, that is use a real service unit file  (bnc#869260)
* Wed Mar  5 2014 cxiong@suse.com
- Add support for in-line environment variable settings
  Handling case like:
  Exec=env GNOME_SHELL_SESSION_MODE=classic gnome --session gnome-classic
  For now, this is only needed to fix session management issue as in bnc#863709.
* Wed Mar  5 2014 cxiong@suse.com
- fix two array iteration bug in etc/X11/xdm/Xsession (xdm.tar.bz2)
  1. "${#argv[@]}" is just the size of the array instead of all the elements,
    i.e. "${argv[@]}", no sharp "#" sign.
  2. index of array starting from 0, so "argc" should be increased at the end
    of iteration loop. (bnc#866874)
* Wed Feb 19 2014 sndirsch@suse.com
- /etc/X11/xdm/keytable: make use of systemd's localectl to
  generate Xserver's configuration snippet for keyboard layout;
  rely on systemd's kbd --> X keyboard mapping; the old mapping
  table originating from SaX2 is no longer being used (bnc#861819)
* Tue Feb 11 2014 dliang@suse.com
- Change the default /etc/X11/xdm/Xsession, (fate#316129)
  don't save standard output information to ~/.xsession-errors
  Modify the xdm.tar.bz2
* Tue Feb  4 2014 coolo@suse.com
- /etc/X11/xdm/RunChooser calls pidof, so require it
* Wed Jan  8 2014 lnussel@suse.de
- don't set twm as hardcoded default if DEFAULT_WM is empty, rely on
  the detection in xinitrc.common instead
* Mon Dec  2 2013 sndirsch@suse.com
- removed u_xdm-sig11-bug-598422.diff
  * problem has been resolved differently
* Fri Oct 18 2013 ferenc.gm@gmail.com
- Added support for qiv in /etc/X11/xdm/Xsetup
* Mon Sep 16 2013 sndirsch@suse.com
- fixed typo in /etc/X11/xdm/Xsetup
* Mon Sep 16 2013 sndirsch@suse.com
- fixed loading of .xkb files (bnc#840408)
* Tue Aug 13 2013 sndirsch@suse.com
- adjusted u_xdm-sig11-bug-598422.diff for openSUSE 12.2 build
  (which still applies xdm-consolekit.diff)
* Mon Jul 29 2013 sndirsch@suse.com
- u_xdm-sig11-bug-598422.diff
  * fix Sig11 in xdm when pressing Ctr-c (bnc#598422, bnc#831870)
* Fri Jun  7 2013 werner@suse.de
- Add some GNOME specifiv magics to Xsession to allow that ~/.i18n
  is always sourced (bnc#567324)
* Fri May 24 2013 werner@suse.de
- Some shells do not know about HOSTNAME variable and print error
  messages therefore export this variable
- Make check for dbus smart, that is check if threre is already
  an active session and use this if possible
- Be aware that one user may use several X sessions in parallel
  on the same system as well as on several systems with HOME on
  an NFS based share. That is do not override ~/.xsession-errors
* Thu Apr 11 2013 sndirsch@suse.com
- do not use '-k' option for checkproc for ssh-agent since
  /proc/<pid>/exe link is apparently not readable by the user
  used for that program (bnc#812783)
* Fri Mar  1 2013 fcrozat@suse.com
- Add systemd-user-sessions to xdm initscript X-Should-Start, to
  ensure user login is available when xdm is started.
* Fri Mar  1 2013 sndirsch@suse.com
- /etc/X11/xdm/SuSEconfig.xdm: copied required function from old
  /lib/YaST/SuSEconfig.functions, which no longer exists since
  openSUSE 12.3 (bnc#806738)
* Tue Jan  8 2013 sndirsch@suse.com
- /etc/X11/xdm/Keyboard.map:
  * added missing mac-dvorak entry (bnc#796170)
* Fri Dec  7 2012 werner@suse.de
- Be aware the mktemp(1) without XXXXXX will do exactly nothing,
  therefore use mv(1) which uses rename(2) on the same file system
  to use the files created by mktemp(1) to the log output file
* Mon Nov 19 2012 fcrozat@suse.com
- Add display-manager as provides to xdm initscript, to comply with
  systemd defaults.
* Thu Nov 15 2012 tittiatcoke@gmail.com
- Added a switch to enable building against systemd-logind and
  to remove the dependency on ConsoleKit
- Enabled the systemd switch already for Factory
* Tue Sep 25 2012 werner@suse.de
- Make failsafe work after a failed exec bash builtin
- Add dbus-launch and ck-launch-session to final session command
  line for case of using xdm
* Thu Sep 13 2012 sndirsch@suse.com
- add dependency on xtrans, otherwise TCP is not supported for
  xdmcp (bnc#780122)
* Thu Aug 16 2012 msrb@suse.cz
- separate *.fallback displaymanager files from xdm.tar.bz2 into
  xdm-fallbacks.tar.bz2 and build only suse version < 1210.
  (bnc#714003)
* Thu Aug 16 2012 msrb@suse.cz
- /etc/init.d/xdm: add plymouth_quit function, use it in xdm
  displaymanager file (bnc#775548)
* Tue Aug  7 2012 sndirsch@suse.com
- /etc/init.d/xdm: overwrite displaymanager's PIDFILE symlink if
  neccessary (bnc#774555)
* Sat Jun 30 2012 tiwai@suse.de
- avoid plymouth quit for kdm and gdm (bnc#762909)
* Fri Jun 29 2012 tiwai@suse.de
- remove --retain-splash option from plymouth quit (bnc#769209)
* Fri Jun 29 2012 sndirsch@suse.com
- /etc/init.d/xdm
  * quit plymouth properly before starting displaymanager
    (bnc#769209)
* Mon Jun 18 2012 werner@suse.de
- Skip LANG argument from command line of session managers (bnc#661946)
* Thu May 10 2012 sndirsch@suse.com
- /etc/pam.d/xdm-np: add session require to pam_loginuid.so in
  order to fix running commands via sudo (bnc #746704)
* Fri Apr 13 2012 vuntz@opensuse.org
- Split xdm from xorg-x11. Initial version: 1.1.10.
